@@ -1,8 +1,8 @@
 ## -*- perl -*-
 ## ----------------------------------------------------------------------
-## DebianDoc_SGML/Format/Driver.pm: DebianDoc-SGML format driver
+## DebianDoc_SGML/Format/Driver: output format generator driver
 ## ----------------------------------------------------------------------
-## Copyright (C) 1998,1999,2000 Ardo van Rangelrooij
+## Copyright (C) 1998-2004 Ardo van Rangelrooij
 ##
 ## This is free software; see the GNU General Public Licence
 ## version 2 or later for copying conditions.  There is NO warranty.
@@ -19,93 +19,76 @@ use Exporter;
 @ISA = qw( Exporter );
 @EXPORT = qw ();
 
-## ----------------------------------------------------------------------
-## set package locations
-use lib "/usr/lib/debiandoc-sgml/lib";
-use lib "/usr/local/lib/debiandoc-sgml/lib";
-
 ## ----------------------------------------------------------------------
 ## import packages
 use DebianDoc_SGML::Format::Alias;
 use DebianDoc_SGML::Locale::Alias;
 use Getopt::Std;
-use POSIX qw( :locale_h );
+use POSIX qw( locale_h );
 use SGMLS::Output;
 
 ## ----------------------------------------------------------------------
 ## get command line options
-use vars qw( $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t );
-getopts( 'b:ce:f:l:mt:' );
+use vars qw( $opt_L $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 );
+getopts( 'Lb:ce:f:l:mt:1' );
 
 ## ----------------------------------------------------------------------
-## get format
-my $format = $opt_f;
-
-## ----------------------------------------------------------------------
-## get format alias
-if ( ! length( $format ) )
+## get format, map and locale
+use vars qw( $format $Format $Map );
+use vars qw( $locale $Locale %locale );
 {
-    die "Error: format not specified\n";
+    $format = $opt_f;
+    if ( ! length( $format ) )
+    {
+	die "Error: format not specified\n";
+    }
+    elsif ( ! defined( $format_aliases{$format} ) )
+    {
+	die "Error: format $format not supported\n";
+    }
+    my $format_alias = $format_aliases{$format};
+    $locale = $opt_l;
+    if ( ! defined( $locale_aliases{$locale} ) )
+    {
+	my $dflt_locale = 'en_US.ISO8859-1';
+	warn "Warning: locale '$locale' not supported, using $dflt_locale\n"
+	    if length( $locale );
+	$locale = $dflt_locale;
+    }
+    my $locale_alias = $locale_aliases{$locale};;
+    $Locale = "DebianDoc_SGML/Locale/$locale_alias/$format_alias";
+    require $Locale;
+    $Locale =~ s|/|::|g;
+    $Map = "DebianDoc_SGML/Map/$format_alias";
+    require "$Map.pm";
+    $Map =~ s|/|::|g;
+    $Format = "DebianDoc_SGML/Format/$format_alias";
+    require "$Format.pm";
+    $Format =~ s|/|::|g;
 }
-elsif ( ! defined( $format_aliases{$format} ) )
-{
-    die "Error: format $format not supported\n";
-}
-my $format_alias = $format_aliases{$format};
-
-## ----------------------------------------------------------------------
-## get locale
-use vars qw( $locale );
-$locale = length( $opt_l ) ? $opt_l : setlocale( 'LANG' );
-
-## ----------------------------------------------------------------------
-## get locale alias
-if ( ! defined( $locale_aliases{$locale} ) )
-{
-    my $dflt_locale = 'en_US.ISO8859-1';
-    warn "Warning: locale $locale not supported, using default $dflt_locale\n";
-    $locale = $dflt_locale;
-}
-my $locale_alias = $locale_aliases{$locale};;
-
-## ----------------------------------------------------------------------
-## load format
-my $Format = "DebianDoc_SGML/Format/$format_alias";
-require "$Format.pm";
-$Format =~ s|/|::|g;
-
-## ----------------------------------------------------------------------
-## load locale
-use vars qw( %i18n );
-my $Locale = "DebianDoc_SGML/Locale/$locale_alias/$format_alias";
-require $Locale;
-$Locale =~ s|/|::|g;
-
-## ----------------------------------------------------------------------
-## load map
-my $Map = "DebianDoc_SGML/Map/$format_alias";
-require "$Map.pm";
-$Map =~ s|/|::|g;
 
 ## ----------------------------------------------------------------------
 ## tag processing
 ## ----------------------------------------------------------------------
 
 ## ----------------------------------------------------------------------
-use vars qw( $element $event %unkown_warn_done );
-use vars qw( @elements @p_lengths );
-use vars qw( $title $abstract );
-use vars qw( $in_author $in_translation );
-use vars qw( @authors @translation_authors );
-use vars qw( $version $translation_version );
-use vars qw( @copyrightsummaries @translation_copyrightsummaries );
-use vars qw( $copyright $translation_copyright );
-use vars qw( $heading_level $toc_detail @indent_levels $indent_level );
-use vars qw( @list_types $list_type @tags @tag );
-use vars qw( @item_counters $item_counter $enumlist_counter );
+use vars qw( @element $element $event %unkown_warn_done );
+use vars qw( @p_length );
+use vars qw( $in_author $in_translator );
+use vars qw( $heading_level $toc_detail );
+use vars qw( @indent_level $indent_level );
+use vars qw( @list_type $list_type );
+use vars qw( @tags @tag );
+use vars qw( @prev_enum_type @enum_type $enum_type );
+use vars qw( @prev_item_counter @item_counter $item_counter );
 use vars qw( $ftpsite $ftppath $httpsite $httppath );
-use vars qw( $will_be_compact @is_compacts $is_compact $was_compact );
+use vars qw( $will_be_compact );
+use vars qw( @is_compact $is_compact );
+use vars qw( @was_compact $was_compact );
 use vars qw( $is_example $is_special );
+use vars qw( $is_argument );
+use vars qw( @is_footnote $is_footnote );
+use vars qw( @in_footnote $in_footnote );
 
 ## ----------------------------------------------------------------------
 sub start
@@ -159,8 +142,8 @@ sub start_titlepag
 }
 sub end_titlepag
 {
+    &{$Format."::"._output_titlepag}();
     $heading_level = 0;
-    &{$Format."::"._output_titlepag}( $heading_level );
 }
 
 ## ----------------------------------------------------------------------
@@ -170,7 +153,7 @@ sub start_title
 }
 sub end_title
 {
-    $title = _normalize( pop_output );
+    &{$Format."::"._output_title}( _normalize( pop_output ) );
 }
 
 ## ----------------------------------------------------------------------
@@ -181,12 +164,22 @@ sub start_author
 }
 sub end_author
 {
-    $in_translation
-	? push( @translation_authors, pop_output )
-	    : push( @authors, pop_output );
+    &{$Format."::"._output_author}( pop_output );
     $in_author = 0;
 }
 
+## ----------------------------------------------------------------------
+sub start_translator
+{
+    $in_translator = 1;
+    push_output( 'string' );
+}
+sub end_translator
+{
+    &{$Format."::"._output_translator}( pop_output );
+    $in_translator = 0;
+}
+
 ## ----------------------------------------------------------------------
 sub start_name
 {
@@ -194,7 +187,7 @@ sub start_name
 }
 sub end_name
 {
-    output( _normalize( pop_output ) );
+    &{$Format."::"._output_name}( _normalize( pop_output ) );
 }
 
 ## ----------------------------------------------------------------------
@@ -204,15 +197,17 @@ sub start_version
 }
 sub end_version
 {
-    ( $in_translation ? $translation_version : $version ) =
-	_normalize( pop_output . '' );
+    &{$Format."::"._output_version}( _normalize( pop_output . '' ) );
 }
 
 ## ----------------------------------------------------------------------
 sub start_date
 {
     @_ = gmtime();
+    my $current_locale = setlocale( LC_TIME );
+    setlocale( LC_TIME, $locale );
     $_ = POSIX::strftime( "%d %B %Y", 0, 0, 0, $_[3], $_[4], $_[5] );
+    setlocale( LC_TIME, $current_locale );
     s/^0//;
     &{$Format."::"._cdata}( $_ );
 }
@@ -227,7 +222,7 @@ sub start_abstract
 }
 sub end_abstract
 {
-    $abstract = pop_output;
+    &{$Format."::"._output_abstract}( pop_output );
 }
 
 ## ----------------------------------------------------------------------
@@ -237,25 +232,7 @@ sub start_copyright
 }
 sub end_copyright
 {
-    ( $in_translation ? $translation_copyright : $copyright ) = pop_output;
-}
-
-## ----------------------------------------------------------------------
-sub start_copyrightsummaries
-{
-}
-sub end_copyrightsummaries
-{
-    if ( $in_translation )
-    {
-	&{$Format."::"._output_copyrightsummaries}( @translation_copyrightsummaries )
-	    if $#translation_copyrightsummaries > -1;
-    }
-    else
-    {
-	&{$Format."::"._output_copyrightsummaries}( @copyrightsummaries )
-	    if $#copyrightsummaries > -1;
-    }
+    &{$Format."::"._output_copyright}( pop_output );
 }
 
 ## ----------------------------------------------------------------------
@@ -265,20 +242,7 @@ sub start_copyrightsummary
 }
 sub end_copyrightsummary
 {
-    $_ = _normalize( pop_output );
-    ( $in_translation
-      ? push( @translation_copyrightsummaries, $_ )
-      : push( @copyrightsummaries, $_ ) );
-}
-
-## ----------------------------------------------------------------------
-sub start_translation
-{
-    $in_translation = 1;
-}
-sub end_translation
-{
-    $in_translation = 0;
+    &{$Format."::"._output_copyrightsummary}( _normalize( pop_output ) );
 }
 
 ## ----------------------------------------------------------------------
@@ -290,19 +254,19 @@ sub start_toc
 }
 sub end_toc
 {
-    &{$Format."::"._output_toc}( pop_output, $heading_level );
+    &{$Format."::"._output_toc}( pop_output );
 }
 
 ## ----------------------------------------------------------------------
 sub start_tocentry
 {
     ( $element, $event ) = @_;
-    push( @elements, $element );
+    push( @element, $element );
     push_output( 'string' );
 }
 sub end_tocentry
 {
-    $element = pop( @elements );
+    $element = pop( @element );
     &{$Format."::"._output_tocentry}( _normalize( pop_output ),
 				      _num_level( _a( 'LEVEL' ) ),
 				      _a( 'CHAPT' ) . _a( 'SECT' ),
@@ -391,12 +355,12 @@ sub end_sect4
 sub start_heading
 {
     ( $element, $event ) = @_;
-    push( @elements, $element );
+    push( @element, $element );
     push_output( 'string' );
 }
 sub end_heading
 {
-    $element = pop( @elements );
+    $element = pop( @element );
     $indent_level = 1 if $indent_level;
     &{$Format."::"._output_heading}( _normalize( pop_output ), $heading_level,
 				     _a( 'CHAPT' ) . _a( 'SECT' ),
@@ -425,8 +389,8 @@ sub start_example
     $paragraph =~ s/^\s+//;
     $paragraph =~ s/\s+$//;
     &{$Format."::"._output_p}( $paragraph );
-    push( @p_lengths, length( $paragraph ) );
-    push( @is_compacts, $is_compact );
+    push( @p_length, length( $paragraph ) );
+    push( @is_compact, $is_compact );
     $is_compact = $is_compact || $will_be_compact;
     push_output( 'string' );
 }
@@ -434,9 +398,9 @@ sub end_example
 {
     my $example = pop_output;
     $example =~ s/\s+$//;
-    &{$Format."::"._output_example}( "$example\n", pop( @p_lengths ) );
+    &{$Format."::"._output_example}( "$example\n", pop( @p_length ) );
     $was_compact = $is_compact;
-    $is_compact = pop( @is_compacts );
+    $is_compact = pop( @is_compact );
     $is_special = 0;
     $is_example = 0;
     push_output( 'string' );
@@ -453,8 +417,8 @@ sub start_include
     $paragraph =~ s/^\s+//;
     $paragraph =~ s/\s+$//;
     &{$Format."::"._output_p}( $paragraph );
-    push( @p_lengths, length( $paragraph ) );
-    push( @is_compacts, $is_compact );
+    push( @p_length, length( $paragraph ) );
+    push( @is_compact, $is_compact );
     $is_compact = $is_compact || $will_be_compact;
     my $source = _a( 'SOURCE' );
     if ( -r $source )
@@ -468,14 +432,14 @@ sub start_include
 	close SOURCE;
 	my $example = pop_output;
 	$example =~ s/\s+$//;
-	&{$Format."::"._output_example}( "$example\n", pop( @p_lengths ) );
+	&{$Format."::"._output_example}( "$example\n", pop( @p_length ) );
     }
     else
     {
 	warn "Warning: include file $source not found\n";
     }
     $was_compact = $is_compact;
-    $is_compact = pop( @is_compacts );
+    $is_compact = pop( @is_compact );
     $is_special = 0;
     $is_example = 0;
     push_output( 'string' );
@@ -487,27 +451,51 @@ sub end_include
 ## ----------------------------------------------------------------------
 sub start_footnote
 {
+    push( @is_compact, $is_compact );
+    $is_compact = 0;
+    push( @was_compact, $was_compact );
+    $was_compact = 0;
+    push( @is_footnote, $is_footnote );
+    $is_footnote = 1;
+    push( @in_footnote, $in_footnote );
+    $in_footnote = 1;
     push_output( 'string' );
 }
 sub end_footnote
 {
     $_ = _trim( pop_output );
     &{$Format."::"._output_footnote}( "$_\n" ) if length( $_ );
+    $in_footnote = pop( @in_footnote );
+    $is_footnote = pop( @is_footnote );
+    $is_compact = pop( @is_compact );
+    $was_compact = pop( @was_compact );
 }
 
 ## ----------------------------------------------------------------------
 sub start_comment
 {
     ( $element, $event ) = @_;
-    push( @elements, $element );
+    push( @is_compact, $is_compact );
+    $is_compact = 0;
+    push( @was_compact, $was_compact );
+    $was_compact = 0;
+    push( @is_footnote, $is_footnote );
+    $is_footnote = 1;
+    push( @in_footnote, $in_footnote );
+    $in_footnote = 1;
+    push( @element, $element );
     push_output( 'string' );
 }
 sub end_comment
 {
     $_ = _trim( pop_output );
-    $element = pop( @elements );
+    $element = pop( @element );
     &{$Format."::"._output_comment}( "$_\n", _a( 'EDITOR' ) )
 	if length( $_ ) && $DebianDoc_SGML::Format::Driver::opt_m;
+    $in_footnote = pop( @in_footnote );
+    $is_footnote = pop( @is_footnote );
+    $is_compact = pop( @is_compact );
+    $was_compact = pop( @was_compact );
 }
 
 ## ----------------------------------------------------------------------
@@ -520,10 +508,12 @@ sub start_list
     $paragraph =~ s/^\s+//;
     $paragraph =~ s/\s+$//;
     &{$Format."::"._output_p}( $paragraph );
-    push( @p_lengths, length( $paragraph ) );
-    push( @is_compacts, $is_compact );
+    push( @p_length, length( $paragraph ) );
+    push( @is_compact, $is_compact );
     $is_compact = $is_compact || $will_be_compact;
-    push( @list_types, $list_type );
+    push( @is_footnote, $is_footnote );
+    $is_footnote = 0;
+    push( @list_type, $list_type );
     $list_type = "list";
     push( @tags, @tag );
     @tag = ();
@@ -534,12 +524,13 @@ sub end_list
 {
     my $list = pop_output;
     $list =~ s/\s+$//;
-    &{$Format."::"._output_list}( "$list\n", pop( @p_lengths ) );
-    $indent_level-- if ( $indent_level - 1 );
+    &{$Format."::"._output_list}( "$list\n", pop( @p_length ) );
+    $indent_level-- if $indent_level > 1;
     @tag = pop( @tags );
-    $list_type = pop( @list_types );
+    $is_footnote = pop( @is_footnote );
+    $list_type = pop( @list_type );
     $was_compact = $is_compact;
-    $is_compact = pop( @is_compacts );
+    $is_compact = pop( @is_compact );
     $is_special = 0;
     push_output( 'string' );
 }
@@ -550,20 +541,66 @@ sub start_enumlist
     ( $element, $event ) = @_;
     $is_special = 1;
     $will_be_compact = $element-> attribute( 'COMPACT' )->type eq 'TOKEN';
+    my $continue = $element-> attribute( 'CONTINUE' )->type eq 'TOKEN';
+    push( @enum_type, $enum_type );
+    if ( $continue )
+    {
+	$enum_type = pop( @prev_enum_type );
+	$enum_type = _a( 'NUMERATION' ) if $enum_type eq '';
+    }
+    else
+    {
+	$enum_type = _a( 'NUMERATION' );
+    }
     my $paragraph = pop_output;
     $paragraph =~ s/^\s+//;
     $paragraph =~ s/\s+$//;
     &{$Format."::"._output_p}( $paragraph );
-    push( @p_lengths, length( $paragraph ) );
-    push( @is_compacts, $is_compact );
+    push( @p_length, length( $paragraph ) );
+    push( @is_compact, $is_compact );
     $is_compact = $is_compact || $will_be_compact;
-    push( @list_types, $list_type );
-    $list_type = "enumlist";
+    push( @is_footnote, $is_footnote );
+    $is_footnote = 0;
+    push( @list_type, $list_type );
+    $list_type = 'enumlist';
     push( @tags, @tag );
     @tag = ();
-    $enumlist_counter++;
-    push( @item_counters, $item_counter );
-    $item_counter = 1;
+    push( @item_counter, $item_counter );
+    $item_counter = pop( @prev_item_counter );
+    if ( $format ne 'html' && $enum_type eq 'UPPERALPHA' )
+    {
+	if ( length( $item_counter) == 0 )
+	{
+	    $item_counter = 'A';
+	}
+	else
+	{
+	    $item_counter = $continue ? $item_counter : 'A';
+	}
+    }
+    elsif ( $format ne 'html' && $enum_type eq 'LOWERALPHA' )
+    {
+	if ( length( $item_counter) == 0 )
+	{
+	    $item_counter = 'a';
+	}
+	else
+	{
+	    $item_counter = $continue ? $item_counter : 'a';
+	}
+    }
+    else
+    {
+	if ( length( $item_counter) == 0 )
+	{
+	    $item_counter = 1;
+	}
+	else
+	{
+	    $item_counter = $continue ? $item_counter : 1;
+	}
+    }
+    push( @item_counter, $item_counter );
     $indent_level++ if $indent_level;
     push_output( 'string' );
 }
@@ -571,14 +608,20 @@ sub end_enumlist
 {
     my $enumlist = pop_output;
     $enumlist =~ s/\s+$//;
-    &{$Format."::"._output_enumlist}( "$enumlist\n", pop( @p_lengths ) );
-    $indent_level-- if ( $indent_level - 1 );
-    $item_counter = pop( @item_counters );
-    $enumlist_counter--;
+    push( @prev_enum_type, $enum_type );
+    push( @prev_item_counter, $item_counter );
+    $item_counter = pop( @item_counter );
+    &{$Format."::"._output_enumlist}( "$enumlist\n",
+				      pop( @p_length ),
+				      $enum_type );
+    $indent_level-- if $indent_level > 1;
+    $enum_type = pop( @enum_type );
+    $item_counter = pop( @item_counter );
     @tag = pop( @tags );
-    $list_type = pop( @list_types );
+    $is_footnote = pop( @is_footnote );
+    $list_type = pop( @list_type );
     $was_compact = $is_compact;
-    $is_compact = pop( @is_compacts );
+    $is_compact = pop( @is_compact );
     $is_special = 0;
     push_output( 'string' );
 }
@@ -593,10 +636,12 @@ sub start_taglist
     $paragraph =~ s/^\s+//;
     $paragraph =~ s/\s+$//;
     &{$Format."::"._output_p}( $paragraph );
-    push( @p_lengths, length( $paragraph ) );
-    push( @is_compacts, $is_compact );
+    push( @p_length, length( $paragraph ) );
+    push( @is_compact, $is_compact );
     $is_compact = $is_compact || $will_be_compact;
-    push( @list_types, $list_type );
+    push( @is_footnote, $is_footnote );
+    $is_footnote = 0;
+    push( @list_type, $list_type );
     $list_type = "taglist";
     push( @tags, @tag );
     @tag = ();
@@ -607,12 +652,13 @@ sub end_taglist
 {
     my $taglist = pop_output;
     $taglist =~ s/\s+$//;
-    &{$Format."::"._output_taglist}( "$taglist\n", pop( @p_lengths ) );
-    $indent_level-- if ( $indent_level - 1 );
+    &{$Format."::"._output_taglist}( "$taglist\n", pop( @p_length ) );
+    $indent_level-- if $indent_level > 1;
     @tag = pop( @tags );
-    $list_type = pop( @list_types );
+    $is_footnote = pop( @is_footnote );
+    $list_type = pop( @list_type );
     $was_compact = $is_compact;
-    $is_compact = pop( @is_compacts );
+    $is_compact = pop( @is_compact );
     $is_special = 0;
     push_output( 'string' );
 }
@@ -631,7 +677,7 @@ sub end_tag
     else
     {
 	my $_output_tag = "_output_" . $list_type . "_tag";
-	&{$Format."::".$_output_tag}( _normalize( pop_output ) );
+	&{$Format."::".$_output_tag}( _normalize( pop_output ), $enum_type );
     }
 }
 
@@ -644,7 +690,8 @@ sub end_item
 {
     $_ = pop_output;
     my $_output_item = "_output_" . $list_type . "_item";
-    &{$Format."::".$_output_item}( $_, \@tag ) if length( $_ );
+    &{$Format."::".$_output_item}( $_, \@tag, $enum_type ) if length( $_ );
+    $item_counter++;
     @tag = ();
 }
 
@@ -731,13 +778,13 @@ sub end_tt
 sub start_qref
 {
     ( $element, $event ) = @_;
-    push( @elements, $element );
+    push( @element, $element );
     push_output( 'string' );
 }
 sub end_qref
 {
     $_ = _trim( pop_output );
-    $element = pop( @elements );
+    $element = pop( @element );
     &{$Format."::"._output_qref}( $_, _a('CSRID'), _a('SRID') )
 	if length( $_ );
 }
@@ -746,13 +793,13 @@ sub end_qref
 sub start_ref
 {
     ( $element, $event ) = @_;
-    push( @elements, $element );
+    push( @element, $element );
     push_output( 'string' );
 }
 sub end_ref
 {
     $_ = _trim( pop_output );
-    $element = pop( @elements );
+    $element = pop( @element );
     &{$Format."::"._output_ref}( $_, _a('HNAME'), _a('CSRID'), _a('SRID') )
 	if length( $_ );
 }
@@ -771,31 +818,33 @@ sub end_manref
 ## ----------------------------------------------------------------------
 sub start_email
 {
+    $is_argument = 1;
     push_output( 'string' );
 }
 sub end_email
 {
     $_ = _trim( pop_output );
     &{$Format."::"._output_email}( $_ ) if length( $_ );
+    $is_argument = 0;
 }
 
 ## ----------------------------------------------------------------------
 sub start_ftpsite
 {
-    $is_example = 1;
+    $is_argument = 1;
     push_output( 'string' );
 }
 sub end_ftpsite
 {
     $ftpsite = _normalize( pop_output );
     &{$Format."::"._output_ftpsite}( $ftpsite ) if length( $ftpsite );
-    $is_example = 0;
+    $is_argument = 0;
 }
 
 ## ----------------------------------------------------------------------
 sub start_ftppath
 {
-    $is_example = 1;
+    $is_argument = 1;
     push_output( 'string' );
 }
 sub end_ftppath
@@ -805,26 +854,26 @@ sub end_ftppath
         print( STDERR
 	       "Warning: FTPPATH \`$_' without preceding FTPSITE\n" );
     &{$Format."::"._output_ftppath}( $ftpsite, $_ ) if length( $_ );
-    $is_example = 0;
+    $is_argument = 0;
 }
 
 ## ----------------------------------------------------------------------
 sub start_httpsite
 {
-    $is_example = 1;
+    $is_argument = 1;
     push_output( 'string' );
 }
 sub end_httpsite
 {
     $httpsite = _normalize( pop_output );
     &{$Format."::"._output_httpsite}( $httpsite ) if length( $httpsite );
-    $is_example = 0;
+    $is_argument = 0;
 }
 
 ## ----------------------------------------------------------------------
 sub start_httppath
 {
-    $is_example = 1;
+    $is_argument = 1;
     push_output( 'string' );
 }
 sub end_httppath
@@ -834,7 +883,7 @@ sub end_httppath
         print( STDERR
 	       "Warning: HTTPPATH \`$_' without preceding HTTPSITE\n" );
     &{$Format."::"._output_httppath}( $httpsite, $_ ) if length( $_ );
-    $is_example = 0;
+    $is_argument = 0;
 }
 
 ## ----------------------------------------------------------------------
@@ -843,10 +892,9 @@ sub start_url
     ( $element, $event ) = @_;
     my $id = _normalize( _a( 'ID' ) );
     my $name = _normalize( _a( 'NAME' ) );
-    $name = "" if $name eq '\|\|' || $name eq '\|urlname\|' || $name eq $id;
-    $is_example = 1;
+    $name = "" if ( $name eq '\|\|' ) || ( $name eq '\|urlname\|' )
+	|| ( $name eq $id );
     &{$Format."::"._output_url}( $id, $name ) if length( $id );
-    $is_example = 0;
 }
 sub end_url
 {
@@ -859,7 +907,6 @@ sub cdata
 }
 sub sdata
 {
-    $_[0] =~ s/\s+//g;
     &{$Format."::"._sdata};
 }
 
@@ -931,6 +978,10 @@ sub _normalize
 ::sgml( '<AUTHOR>', \&start_author );
 ::sgml( '</AUTHOR>', \&end_author );
 
+## ----------------------------------------------------------------------
+::sgml( '<TRANSLATOR>', \&start_translator );
+::sgml( '</TRANSLATOR>', \&end_translator );
+
 ## ----------------------------------------------------------------------
 ::sgml( '<NAME>', \&start_name );
 ::sgml( '</NAME>', \&end_name );
@@ -951,10 +1002,6 @@ sub _normalize
 ::sgml( '<COPYRIGHT>', \&start_copyright );
 ::sgml( '</COPYRIGHT>', \&end_copyright );
 
-## ----------------------------------------------------------------------
-::sgml( '<COPYRIGHTSUMMARIES>', \&start_copyrightsummaries );
-::sgml( '</COPYRIGHTSUMMARIES>', \&end_copyrightsummaries );
-
 ## ----------------------------------------------------------------------
 ::sgml( '<COPYRIGHTSUMMARY>', \&start_copyrightsummary );
 ::sgml( '</COPYRIGHTSUMMARY>', \&end_copyrightsummary );
